from dataclasses import dataclass, field
from typing import Dict, List


@dataclass
class DemoConfig:
    default_channel: str = "discord"
    enabled_channels: List[str] = field(
        default_factory=lambda: ["discord", "telegram", "whatsapp"]
    )
    bindings: Dict[str, str] = field(default_factory=dict)


def load_config() -> DemoConfig:
    return DemoConfig()

