from typing import List

import typer


def try_route_cli(argv: List[str]) -> bool:
    if len(argv) < 2:
        return False
    cmd = argv[1]
    if cmd == "health":
        typer.echo("ok")
        raise typer.Exit(code=0)
    if cmd == "status":
        typer.echo("demo-status: healthy")
        raise typer.Exit(code=0)
    return False

